changeset 15866:38a12fe3e755 draft

(svn r20548) -Codechange: rename some variables giving them slightly more meaningful names
author rubidium <rubidium@openttd.org>
date Wed, 18 Aug 2010 21:30:38 +0000
parents 270f9b0689cc
children 86e5c7c3222e
files src/network/core/tcp_game.h src/network/network_command.cpp src/network/network_server.cpp
diffstat 3 files changed, 9 insertions(+), 9 deletions(-) [+]
line wrap: on
line diff
--- a/src/network/core/tcp_game.h
+++ b/src/network/core/tcp_game.h
@@ -122,7 +122,7 @@
 
 	ClientStatus status;      ///< Status of this client
 
-	CommandQueue command_queue; ///< The command-queue awaiting delivery
+	CommandQueue outgoing_queue; ///< The command-queue awaiting delivery
 
 	NetworkRecvStatus CloseConnection(bool error = true);
 
--- a/src/network/network_server.cpp
+++ b/src/network/network_server.cpp
@@ -1612,7 +1612,7 @@
 static void NetworkHandleCommandQueue(NetworkClientSocket *cs)
 {
 	CommandPacket *cp;
-	while ((cp = cs->command_queue.Pop()) != NULL) {
+	while ((cp = cs->outgoing_queue.Pop()) != NULL) {
 		SEND_COMMAND(PACKET_SERVER_COMMAND)(cs, cp);
 		free(cp);
 	}
--- a/src/network/network_command.cpp
+++ b/src/network/network_command.cpp
@@ -97,8 +97,8 @@
 }
 
 
-/** Local queue of packets */
-static CommandQueue _local_command_queue;
+/** Local queue of packets waiting for execution. */
+static CommandQueue _local_execution_queue;
 
 /**
  * Add a command to the local or client socket command queue,
@@ -110,7 +110,7 @@
 {
 	CommandPacket *new_cp = MallocT<CommandPacket>(1);
 	*new_cp = cp;
-	(cs == NULL ? _local_command_queue : cs->command_queue).Append(new_cp);
+	(cs == NULL ? _local_execution_queue : cs->outgoing_queue).Append(new_cp);
 }
 
 /**
@@ -177,7 +177,7 @@
  */
 void NetworkSyncCommandQueue(NetworkClientSocket *cs)
 {
-	for (CommandPacket *p = _local_command_queue.Peek(); p != NULL; p = p->next) {
+	for (CommandPacket *p = _local_execution_queue.Peek(); p != NULL; p = p->next) {
 		CommandPacket c = *p;
 		c.callback = 0;
 		c.next = NULL;
@@ -193,7 +193,7 @@
 	assert(IsLocalCompany());
 
 	CommandPacket *cp;
-	while ((cp = _local_command_queue.Peek()) != NULL) {
+	while ((cp = _local_execution_queue.Peek()) != NULL) {
 		/* The queue is always in order, which means
 		 * that the first element will be executed first. */
 		if (_frame_counter < cp->frame) break;
@@ -209,7 +209,7 @@
 		cp->cmd |= CMD_NETWORK_COMMAND;
 		DoCommandP(cp, cp->my_cmd);
 
-		_local_command_queue.Pop();
+		_local_execution_queue.Pop();
 		free(cp);
 	}
 
@@ -222,7 +222,7 @@
  */
 void NetworkFreeLocalCommandQueue()
 {
-	_local_command_queue.Free();
+	_local_execution_queue.Free();
 }
 
 /**